@@ -5,45 +5,6 @@ from fastapi.encoders import jsonable_encoder
 from bson import ObjectId
 from pydantic.json import ENCODERS_BY_TYPE
 
-""" Enums and global dicts """
-
-
-class LightingDeviceType:
-    KasaBulb: str = "Kasa Bulb"
-    CustomLedStrip: str = "Custom Led Strip"
-    KasaLedStrip: str = "Kasa Led Strip"
-
-
-class PowerDeviceType:
-    KasaPlug: str = "Kasa Plug"
-
-
-class DisplayDeviceType:
-    Chromecast: str = "Chromecast"
-
-
-class ServiceUrls:
-    LIGHTING_SERVICE_URL = "http://.default.svc.cluster.local:8000"
-    POWER_SERVICE_URL = "http://power-service-cluster-ip.default.svc.cluster.local:8000"
-    SCENE_SERVICE_URL = "http://scene-service-cluster-ip.default.svc.cluster.local:8000"
-    DEVICE_SERVICE_URL = "http://device-service-cluster-ip.default.svc.cluster.local:8000"
-    DISPLAY_SERVICE_URL = "http://display-service-cluster-ip.default.svc.cluster.local:8000"
-    MEDIA_DRIVE_SERVICE_URL = "http://media-drive-service-cluster-ip.default.svc.cluster.local:8000"
-    CHROMECAST_CONTROLLER_URL = "http://chromecast-controller-cluster-ip.default.svc.cluster.local:8000"
-    KASA_LED_STRIP_CONTROLLER_URL = "http://kasa-led-strip-controller-cluster-ip.default.svc.cluster.local:8000"
-    KASA_BULB_CONTROLLER_URL = "http://kasa-bulb-controller-cluster-ip.default.svc.cluster.local:8000"
-    KASA_PLUG_CONTROLLER_URL = "http://kasa-plug-controller-cluster-ip.default.svc.cluster.local:8000"
-
-
-class DeviceControllerProxy:
-    device_model_to_url = {
-        LightingDeviceType.KasaBulb: ServiceUrls.KASA_BULB_CONTROLLER_URL,
-        LightingDeviceType.KasaLedStrip: ServiceUrls.KASA_LED_STRIP_CONTROLLER_URL,
-        PowerDeviceType.KasaPlug: ServiceUrls.KASA_PLUG_CONTROLLER_URL,
-        DisplayDeviceType.Chromecast: ServiceUrls.CHROMECAST_CONTROLLER_URL
-    }
-
-
 """ Model Groundwork """
 
 
@@ -81,6 +42,50 @@ class IccBaseModel(BaseModel):
         return data
 
 
+""" Enums and global dicts """
+
+
+class DeviceType:
+    Lighting: str = "Lighting"
+    Power: str = "Power"
+
+
+class LightingDeviceType:
+    KasaBulb: str = "Kasa Bulb"
+    CustomLedStrip: str = "Custom Led Strip"
+    KasaLedStrip: str = "Kasa Led Strip"
+
+
+class PowerDeviceType:
+    KasaPlug: str = "Kasa Plug"
+
+
+class DisplayDeviceType:
+    Chromecast: str = "Chromecast"
+
+
+class ServiceUrls:
+    LIGHTING_SERVICE_URL = "http://.default.svc.cluster.local:8000"
+    POWER_SERVICE_URL = "http://power-service-cluster-ip.default.svc.cluster.local:8000"
+    SCENE_SERVICE_URL = "http://scene-service-cluster-ip.default.svc.cluster.local:8000"
+    DEVICE_SERVICE_URL = "http://device-service-cluster-ip.default.svc.cluster.local:8000"
+    DISPLAY_SERVICE_URL = "http://display-service-cluster-ip.default.svc.cluster.local:8000"
+    MEDIA_DRIVE_SERVICE_URL = "http://media-drive-service-cluster-ip.default.svc.cluster.local:8000"
+    CHROMECAST_CONTROLLER_URL = "http://chromecast-controller-cluster-ip.default.svc.cluster.local:8000"
+    KASA_LED_STRIP_CONTROLLER_URL = "http://kasa-led-strip-controller-cluster-ip.default.svc.cluster.local:8000"
+    KASA_BULB_CONTROLLER_URL = "http://kasa-bulb-controller-cluster-ip.default.svc.cluster.local:8000"
+    KASA_PLUG_CONTROLLER_URL = "http://kasa-plug-controller-cluster-ip.default.svc.cluster.local:8000"
+
+
+class DeviceControllerProxy:
+    device_model_to_url = {
+        LightingDeviceType.KasaBulb: ServiceUrls.KASA_BULB_CONTROLLER_URL,
+        LightingDeviceType.KasaLedStrip: ServiceUrls.KASA_LED_STRIP_CONTROLLER_URL,
+        PowerDeviceType.KasaPlug: ServiceUrls.KASA_PLUG_CONTROLLER_URL,
+        DisplayDeviceType.Chromecast: ServiceUrls.CHROMECAST_CONTROLLER_URL
+    }
+
+
 """ DTOs """
 
 
@@ -106,7 +111,6 @@ class PowerRequest(IccBaseModel):
 
 class SceneRequestDto(IccBaseModel):
     name: str
-    date: datetime = datetime.utcnow().isoformat()
 
 
 class ChromecastRequest(IccBaseModel):
@@ -143,6 +147,25 @@ class DeviceDto(IccBaseModel):
     model: str
 
 
+""" Analytics Record Models """
+
+
+class LightingRequestRecord(IccBaseModel):
+    target_id: PydanticObjectId
+    operation: str
+    h: int | None
+    s: int | None
+    v: int | None
+    brightness: int | None
+    temperature: int | None
+    time: str
+
+
+class SceneRequestRecord(IccBaseModel):
+    name: str
+    time: str
+
+
 """ Entitity Models """
 
 
@@ -154,13 +177,6 @@ class Device(IccBaseModel):
     ip: str
 
 
-class State(IccBaseModel):
-    id: Optional[PydanticObjectId] = Field(None, alias="_id")
-    device: PydanticObjectId
-    state: bool
-    date: datetime = datetime.utcnow()
-
-
 class SceneModel(IccBaseModel):
     id: PydanticObjectId = Field(None, alias="_id")
     name: str
@@ -173,5 +189,4 @@ class DeviceModel(IccBaseModel):
     name: str
     ip: str
     type: str
-    state: State
     model: str
